import * as React from 'react';
import { ButtonGroupAlignment } from "./ButtonGroupAlignment";
import { ButtonGroupSelection } from "./ButtonGroupSelection";
import { IgrComponentValueChangedEventArgs } from "./igr-component-value-changed-event-args";
import { ButtonGroup } from "./ButtonGroup";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
/**
 * The `igc-button-group` groups a series of `igc-toggle-button`s together, exposing features such as layout and selection.
*/
export declare class IgrButtonGroup<P extends IIgrButtonGroupProps = IIgrButtonGroupProps> extends React.Component<P, {}> {
    protected createImplementation(): ButtonGroup;
    protected _implementation: any;
    protected mounted: boolean;
    /**
     * @hidden
     */
    get i(): ButtonGroup; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrButtonGroup;
    protected _renderer: ReactRenderer;
    protected _portalManager: PortalManager;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        id: P["id"];
        class: P["className"];
        style: P["style"];
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * Disables all buttons inside the group.
    */
    get disabled(): boolean;
    set disabled(v: boolean);
    /**
     * Sets the orientation of the buttons in the group.
    */
    get alignment(): ButtonGroupAlignment;
    set alignment(v: ButtonGroupAlignment);
    /**
     * Controls the mode of selection for the button group.
    */
    get selection(): ButtonGroupSelection;
    set selection(v: ButtonGroupSelection);
    get selectedItems(): string[];
    set selectedItems(v: string[]);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    setNativeElement(element: any): void;
    private _select;
    private _select_wrapped;
    get select(): (s: IgrButtonGroup, e: IgrComponentValueChangedEventArgs) => void;
    set select(ev: (s: IgrButtonGroup, e: IgrComponentValueChangedEventArgs) => void);
    private _deselect;
    private _deselect_wrapped;
    get deselect(): (s: IgrButtonGroup, e: IgrComponentValueChangedEventArgs) => void;
    set deselect(ev: (s: IgrButtonGroup, e: IgrComponentValueChangedEventArgs) => void);
}
export interface IIgrButtonGroupProps {
    children?: React.ReactNode;
    id?: string | undefined;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * Disables all buttons inside the group.
    */
    disabled?: boolean | string;
    /**
     * Sets the orientation of the buttons in the group.
    */
    alignment?: ButtonGroupAlignment | string;
    /**
     * Controls the mode of selection for the button group.
    */
    selection?: ButtonGroupSelection | string;
    selectedItems?: string[];
    select?: (s: IgrButtonGroup, e: IgrComponentValueChangedEventArgs) => void;
    deselect?: (s: IgrButtonGroup, e: IgrComponentValueChangedEventArgs) => void;
}
